@@ -10,4 +10,7 @@ def mediaObjectAdded(ob, event):
         folder = ob['slideshow']
         
         folder.reindexObject()
-        folder.portal_workflow.doActionFor(folder, "publish", comment="Slideshow content automatically published")
\ No newline at end of file
+        try:
+            folder.portal_workflow.doActionFor(folder, "publish", comment="Slideshow content automatically published")
+        except:
+            pass
\ No newline at end of file
